/****************************************************************************
** $Id:  cmds/cmds.cpp
** AutoQ3D a qt 3d model editor program
**
** Copyright (C) 2005 -Gonzalo Reynaga Garca. <gonzaloreynaga@yahoo.com>
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public Licence
** as published by the Free Software Foundation; either version 2 
** of the License, or (at your option) any later option.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
** 
*****************************************************************************/


#include "cmds.h"

#include "cmddrawline.h"
#include "cmddrawtriangle.h"
#include "cmdzoom.h"
#include "cmdpan.h"
#include "cmdrotateview.h"
#include "cmdpopzoom.h"
#include "cmdpoppan.h"
#include "cmdpoprotateview.h"
#include "cmdgriponlymove.h"
#include "cmdgriponlyscale.h"
#include "cmdgriponlymirror.h"
#include "cmdgriponlystretch.h"
#include "cmdgriponlyrotate.h"
#include "cmdquickerase.h"
#include "cmdshowproperties.h"
#include "cmdrotate3d.h"
#include "cmdextrude.h"
#include "cmdarray.h"
#include "cmdmeannormals.h"
#include "cmdslice.h"
#include "cmdcube.h"
#include "cmddist.h"
#include "cmdswitch.h"
#include "cmdtrinormals.h"
#include "cmdsnap.h"
#include "cmdrevolve.h"
#include "cmddrawpoly.h"


cmds::cmds( QWidget* parent)
    :  QTextEdit(parent)
{		
	Props= new ProperDiag(0);
	DataSTV.resize(0);
	DataSLV.resize(0);
	DataSV.resize(0);

	step=0;
	cscalarf[0]=1;
	PopStep=0;
	PopViewMode=0;
	CommandActive=0;
	SnapFlags[0]=0;
	GripEditMode[0]=0;
	SnapMode[0]=0;
	SnaPoint->find=0;
	tempdataI[0]=0;
	rtlines[0].find=0;
	rtlines[1].find=0;
	GriPoint[0].find=0;
	SecCmd="BlankCommand";


	QPalette newPalette = QPalette();
	newPalette.setColor(QPalette::Background, QColor::QColor(170,170,255));
	newPalette.setColor(QPalette::Foreground, QColor::QColor(0,0,0));
	newPalette.setColor(QPalette::Base, QColor::QColor(170,170,255));

	setPalette(newPalette);
	
	cmdlist["l"]=			CMDDRAWLINE;
	cmdlist["line"]=		CMDDRAWLINE;
	cmdlist["pl"]=			CMDDRAWLINE;
	cmdlist["polyline"]=	CMDDRAWLINE;
	cmdlist["tri"]=			CMDDRAWTRIANGLE;
	cmdlist["triangle"]=	CMDDRAWTRIANGLE;
	cmdlist["**Cancel**"]=	CMDCANCEL;
	cmdlist["z"]=			CMDZOOM;
	cmdlist["zoom"]=		CMDZOOM;
	cmdlist["'z"]=			CMDZOOM;
	cmdlist["'zoom"]=		CMDZOOM;
	cmdlist["p"]=			CMDPAN;
	cmdlist["pan"]=			CMDPAN;
	cmdlist["'p"]=			CMDPAN;
	cmdlist["'pan"]=		CMDPAN;
	cmdlist["rtv"]=			CMDROTATEVIEW;
	cmdlist["rotateview"]=	CMDROTATEVIEW;
	cmdlist["'rtv"]=		CMDROTATEVIEW;
	cmdlist["'rotateview"]=	CMDROTATEVIEW;
	cmdlist["gripmove"]=	CMDGRIPONLYMOVE;
	cmdlist["gripscale"]=	CMDGRIPONLYSCALE;
	cmdlist["gripmirror"]=	CMDGRIPONLYMIRROR;
	cmdlist["gripstretch"]=	CMDGRIPONLYSTRETCH;
	cmdlist["griprotate"]=	CMDGRIPONLYROTATE;
	cmdlist["e"]=			CMDQUICKERASE;
	cmdlist["erase"]=		CMDQUICKERASE;
	cmdlist["proper"]=		CMDSHOWPROPERTIES;
	cmdlist["properties"]=	CMDSHOWPROPERTIES;
	cmdlist["rotate3d"]=	CMDROTATE3D;
	cmdlist["extrude"]=		CMDEXTRUDE;
	cmdlist["array"]=		CMDARRAY;
	cmdlist["mnormals"]=	CMDMEANNORMALS;
	cmdlist["slice"]=		CMDSLICE;
	cmdlist["rectangle"]=	CMDCUBE;
	cmdlist["dist"]=		CMDDIST;
	cmdlist["switch"]=		CMDSWITCH;
	cmdlist["trinormals"]=	CMDTRINORMALS;
	cmdlist["snap"]=		CMDSNAP;
	cmdlist["'snap"]=		CMDSNAP;
	cmdlist["revolve"]=		CMDREVOLVE;
	cmdlist["poly"]=		CMDDRAWPOLY;
	cmdlist["polygon"]=		CMDDRAWPOLY;

	

}

void cmds::setDataL(QVector<d3line> *Info,QVector<d3triangle> *Infotri,int *mousei){
	DataLV=Info;
	DataTV=Infotri;
	MouseMode=mousei;
}

cmds::~cmds()
{

}


void cmds::SendText(QString str)
{
	append(str);
	verticalScrollBar()->setValue(verticalScrollBar()->maximum());

}



void cmds::processcmd(QString str){


	
	if(CommandActive){
		SecCmd=str;
	}else{
		if(!cmdlist.value(str,0)){
			if(!str.compare("setCmdData")){
				append("Command not found");
				verticalScrollBar()->setValue(verticalScrollBar()->maximum());
				return;
			}
			append(str);
			append("Command not found");
			verticalScrollBar()->setValue(verticalScrollBar()->maximum());
			return;
		}
		currentcmd=str;
		SecCmd="BlankCommand";
		CommandActive=1;
	}
	
	
		switch(cmdlist[currentcmd]){
			case CMDCANCEL:
				DataSV.resize(0);
				append("**Cancel**");
				verticalScrollBar()->setValue(verticalScrollBar()->maximum());
				CmdCancel();
				
			break;
			case CMDDRAWLINE:
				cmddrawline();
			break;
			case CMDDRAWTRIANGLE:
				cmddrawtriangle();
			break;
			case CMDZOOM:
				cmdzoom();
			break;
			case CMDPAN:
				cmdpan();
			break;
			case CMDROTATEVIEW:
				cmdrotateview();
			break;
			case CMDGRIPONLYMOVE:
				cmdgriponlymove();
			break;
			case CMDGRIPONLYSCALE:
				cmdgriponlyscale();
			break;
			case CMDGRIPONLYMIRROR:
				cmdgriponlymirror();
			break;
			case CMDQUICKERASE:
				SendText("erase");
				cmdquickerase();
			break;
			case CMDGRIPONLYSTRETCH:
				cmdgriponlystretch();
			break;
			case CMDGRIPONLYROTATE:
				cmdgriponlyrotate();
			break;
			case CMDSHOWPROPERTIES:
				cmdshowproperties();
			break;
			case CMDROTATE3D:
				cmdrotate3d();
			break;
			case CMDEXTRUDE:
				cmdextrude();
			break;
			case CMDARRAY:
				cmdarray();
			break;
			case CMDMEANNORMALS:
				cmdmeannormals();
			break;
			case CMDSLICE:
				cmdslice();
			break;
			case CMDCUBE:
				cmdcube();
			break;
			case CMDDIST:
				cmddist();
			break;
			case CMDSWITCH:
				cmdswitch();
			break;
			case CMDTRINORMALS:
				cmdtrinormals();
			break;
			case CMDSNAP:
				cmdsnap();
			break;
			case CMDREVOLVE:
				cmdrevolve();
			break;
			case CMDDRAWPOLY:
				cmddrawpoly();
			break;
		}
	
}

void cmds::setCmdData(dataformat data){

	currentdata=data;
	processcmd("setCmdData");
	verticalScrollBar()->setValue(verticalScrollBar()->maximum());
}

void cmds::CmdCancel(){
			rtlines[0].find=0;
			rtlines[1].find=0;
			emit SetMouseMode(MOUSEMODE_SELECT);
			emit instru("Command:");
			CommandActive=0;
			step=0;SecCmd="BlankCommand";
			GripEditMode[0]=0;
			DataSLV.resize(0);
			DataSTV.resize(0);
			GriPoint->find=0;
			SnaPoint->find=0;
}

int cmds::CmdSelectPopView(){
			
			if(PopViewMode==1){cmdpopzoom();return 1;}
			if(PopViewMode==2){cmdpoppan();return 1;}
			if(PopViewMode==3){cmdpoprotateview();return 1;}
			
			if(!SecCmd.compare("'z")||!SecCmd.compare("'zoom")){
				PopViewMode=1;cmdpopzoom();return 1;
			}
			
			if(!SecCmd.compare("'p")||!SecCmd.compare("'pan")){
				PopViewMode=2;cmdpoppan();return 1;
			}
			if(!SecCmd.compare("'rtv")||!SecCmd.compare("'rotateview")){
				PopViewMode=3;cmdpoprotateview();return 1;
			}
			
	
	return 0;
}


int cmds::CmdCheckSnap(){
			if(!SecCmd.compare("'snap")){
				if(SnapMode[0]==0){
					SendText("--Snap ON (endpoint)--");
					SnapMode[0]=1;
				}else{
					SnapMode[0]=0;
					SendText("--Snap OFF--");
				}
				return 1;
			}
			if(!SecCmd.compare("end")||!SecCmd.compare("END")){
				SnapMode[0]=1;
				SendText("end of");
				return 1;
			}
			
			if(!SecCmd.compare("mid")||!SecCmd.compare("MID")){
				SnapMode[0]=2;
				SendText("mid of");
				return 1;
			}
			
			
	return 0;
}

