/****************************************************************************
** $Id:  dialogs/viewprop.cpp
** AutoQ3D a qt 3d model editor program
**
** Copyright (C) 2005 -Gonzalo Reynaga Garca. <gonzaloreynaga@yahoo.com>
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public Licence
** as published by the Free Software Foundation; either version 2 
** of the License, or (at your option) any later option.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
** 
*****************************************************************************/

#include "viewprop.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

/*
 *  Constructs a Viewprop as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
Viewprop::Viewprop( QWidget* parent, Qt::WFlags fl )
    : QDialog( parent, fl )
{
    ViewpropLayout = new QVBoxLayout(this); 
    
	
	EFar = new QLineEdit;
	ENear = new QLineEdit;
	Label2 = new QLabel(  "Near depth clipping plane" );
	Label3 = new QLabel(  "Far depth clipping plane" );
	
	chBW = new QCheckBox("Wireframe");
	NSize = new QLineEdit;
	Label1 = new QLabel(  "Normal size" );
	chBN = new QCheckBox(  "Show Normals" );
	Label1->setAlignment(Qt::AlignRight);

	OkBtn = new QPushButton(  "OK" );
	CancelBtn = new QPushButton(  "Cancel" );

	QHBoxLayout *buttonLayout = new QHBoxLayout;
    buttonLayout->addStretch(1);
    buttonLayout->addWidget(OkBtn);
    buttonLayout->addWidget(CancelBtn);

	QHBoxLayout *checkLayout = new QHBoxLayout;
    checkLayout->addWidget(chBW);
    checkLayout->addWidget(chBN);
	checkLayout->addStretch(1);


	QHBoxLayout *NSizeLayout = new QHBoxLayout;
	NSizeLayout->addWidget(Label1,Qt::AlignRight);
	NSizeLayout->addWidget(NSize);
	NSizeLayout->addStretch(1);

	layout1 = new QGridLayout;
	layout1->addWidget(Label2,0,0,Qt::AlignBottom);
    layout1->addWidget(Label3,0,1,Qt::AlignBottom);
	layout1->addWidget(ENear,1,0,Qt::AlignTop);
    layout1->addWidget(EFar,1,1,Qt::AlignTop);
	
	
    ViewpropLayout->addLayout(checkLayout);
	ViewpropLayout->addStretch(1);
	ViewpropLayout->addLayout(NSizeLayout);
	ViewpropLayout->addLayout(layout1);
	ViewpropLayout->addStretch(1);
	ViewpropLayout->addLayout(buttonLayout);
	
	setWindowTitle(  "Viewport Properties" );
	
	EFar->setValidator(new QDoubleValidator(EFar));
	ENear->setValidator(new QDoubleValidator(ENear));
	NSize->setValidator(new QDoubleValidator(NSize));
   
    
    resize( QSize(327, 202).expandedTo(minimumSizeHint()) );
	connect( OkBtn, SIGNAL( clicked() ) , this, SLOT( accept() ) );
	connect( CancelBtn, SIGNAL( clicked() ) , this, SLOT( reject() ) );
}

/*
 *  Destroys the object and frees any allocated resources
 */
Viewprop::~Viewprop()
{
    // no need to delete child widgets, Qt does it all for us
}


